@@ -3,7 +3,7 @@ import subprocess
 import atexit
 import signal
 import sys
-from django_grunt.utils import GruntRootMixin
+from grunt.utils import GruntRootMixin
 from django.conf import settings
 from django.core.management.base import CommandError
 from django.contrib.staticfiles.management.commands.runserver import Command\
